from setuptools import setup

setup(name='udc_mlnd_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['udc_mlnd_probability'],
      author='Chukwuemeka Ezumezu',
      author_email='emyfrancis2012@gmail.com',
      zip_safe=False)
